@@ -2,8 +2,6 @@ use crate::{
   objects::{community::ApubCommunity, person::ApubPerson, post::ApubPost},
   protocol::{ImageObject, Source, Unparsed},
 };
-use activitystreams_kinds::object::PageType;
-use anyhow::anyhow;
 use chrono::{DateTime, FixedOffset};
 use lemmy_apub_lib::{
   data::Data,
@@ -17,6 +15,12 @@ use serde::{Deserialize, Serialize};
 use serde_with::skip_serializing_none;
 use url::Url;
 
+#[derive(Clone, Debug, Deserialize, Serialize)]
+pub enum PageType {
+  Page,
+  Note,
+}
+
 #[skip_serializing_none]
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[serde(rename_all = "camelCase")]
@@ -71,11 +75,14 @@ impl Page {
     loop {
       if let Some(cid) = to_iter.next() {
         let cid = ObjectId::new(cid.clone());
-        if let Ok(c) = cid.dereference(context, request_counter).await {
+        if let Ok(c) = cid
+          .dereference(context, context.client(), request_counter)
+          .await
+        {
           break Ok(c);
         }
       } else {
-        return Err(anyhow!("No community found in cc").into());
+        return Err(LemmyError::from_message("No community found in cc"));
       }
     }
   }
